mathtools.is_positive_integer_equivalent_number
===============================================

.. autofunction:: abjad.tools.mathtools.is_positive_integer_equivalent_number.is_positive_integer_equivalent_number
